@@ -308,18 +308,18 @@ class EmojiPickerUI(Gtk.Window):
         self._main_menu_popover.set_position(Gtk.PositionType.BOTTOM)
         self._main_menu_popover_vbox = Gtk.VBox()
         self._main_menu_clear_recently_used_button = Gtk.Button(
-            _('Clear recently used'))
+            label=_('Clear recently used'))
         self._main_menu_clear_recently_used_button.connect(
             'clicked', self.on_clear_recently_used_button_clicked)
         self._main_menu_popover_vbox.pack_start(
             self._main_menu_clear_recently_used_button, False, False, 0)
         if not self._modal:
-            self._main_menu_about_button = Gtk.Button(_('About'))
+            self._main_menu_about_button = Gtk.Button(label=_('About'))
             self._main_menu_about_button.connect(
                 'clicked', self.on_about_button_clicked)
             self._main_menu_popover_vbox.pack_start(
                 self._main_menu_about_button, False, False, 0)
-        self._main_menu_quit_button = Gtk.Button(_('Quit'))
+        self._main_menu_quit_button = Gtk.Button(label=_('Quit'))
         self._main_menu_quit_button.connect('clicked', self.on_delete_event)
         self._main_menu_popover_vbox.pack_start(
             self._main_menu_quit_button, False, False, 0)
@@ -456,6 +456,12 @@ class EmojiPickerUI(Gtk.Window):
 
         self._emoji_by_label = self._emoji_matcher.emoji_by_label()
         expanded_languages = itb_emoji.expand_languages(self._languages)
+        # 'en_001' and 'es_419' are not very useful in the treeview to browse the
+        # languages, remove them from the list:
+        expanded_languages = [
+            lang
+            for lang in expanded_languages
+            if lang not in ('en_001', 'es_419')]
         first_language_with_categories = -1
         number_of_empty_languages = 0
         for language_index, language in enumerate(expanded_languages):
@@ -2026,7 +2032,8 @@ class EmojiPickerUI(Gtk.Window):
         '''
         good_emoji_fonts = [
             'Noto Color Emoji 🎨',
-            'Apple Color Emoji 🎨',
+            'Twemoji 🎨', # color
+            'Apple Color Emoji 🎨', # color
             'Emoji Two 🎨', # color
             'Emoji One 🎨', # color
             'Symbola 🙾', # black and white
